@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 #  Copyright (C) 2011-2012 Travis Cline
 #
@@ -6,7 +5,7 @@
 #  It is adapted from upstream project zeromq_gevent under the New BSD License
 #
 #  Distributed under the terms of the New BSD License.  The full license is in
-#  the file COPYING.BSD, distributed as part of this software.
+#  the file LICENSE.BSD, distributed as part of this software.
 # -----------------------------------------------------------------------------
 
 """zmq.green - gevent compatibility with zeromq.
@@ -29,6 +28,9 @@ before any blocking operation and the ØMQ file descriptor is polled internally
 to trigger needed events.
 """
 
+from typing import List
+
+import zmq as _zmq
 from zmq import *
 from zmq.green.core import _Context, _Socket
 from zmq.green.poll import _Poller
@@ -38,3 +40,7 @@ Socket = _Socket  # type: ignore
 Poller = _Poller  # type: ignore
 
 from zmq.green.device import device  # type: ignore
+
+__all__: List[str] = []
+# adding `__all__` to __init__.pyi gets mypy all confused
+__all__.extend(_zmq.__all__)  # type: ignore
